get_issues_by_date: Query information
about issues within a date-time range.
Description
Returns all issues
within a date-time window in the specified location, specified either by
coordinates or by name/address.
Usage
get_issues_by_date(city, after =
Sys.time() - 86400, before = Sys.time(), status =
"open,acknowledged,closed,archived", limit = 100)
Arguments
city
A
written description of the location for which issue types should be returned.
If city is specified, lat/long should not be.
after
Beginning of
time window from which issues should be returned. Specified in POSIX date-time
format. Defaults to 24 hours prior to system time.
before
End of
time window from which issues should be returned. Specified in POSIX date-time
format. Defaults to system time.
status
Which status types of issues
should be returned. Separate statuses should be separated by commas without
spaces. Available options are open, acknowledged, closed, and archived.
Default is all.
limit
Number of items to return. Defaults to 100.
Value
issue_idUnique ID number for the given issue
statusStatus of the issue (open/acknowledged/closed)
summarySummary of the status for the issue
descriptionText
description of the issue as reported
ratingImportance rating of the
issue
latLatitude of the issue as reported
lngLongitude of
the issue as reported
issue_addressAddress of the issue as reported
created_atDate and time when issue report was created
acknowledged_atDate and time when issue report was acknowledged by
city
closed_atDate and time when issue report was closed by city
reopened_atDate and time when issue report was reopened, if it was
updated_atDate and time when issue report was last updated
shortened_urlShortened URL of the issue report
video_urlURL
for the video of the issue, if provided
image_fullImage of the issue
as reported
image_square_100x100Square version of the image of the
issue
representative_image_urlA representative image of the issue, if
no actual image was submitted
issue_typeType of issue
urlURL
to the report of the issue
html_urlURL to the report of the issue in
HTML format
comment_urlURL to the comments on the issue
flag_urlURL to the flag for the issue
close_urlURL to the
closing report of the issue
open_urlURL to the opening report of the
issue
reporter_idIssue reporter's unique ID number
reporter_nameName of the issue reporter
reporter_wittytitleUsername/witty name of the issue reporter
reporter_roleIssue reporter's role in the city, if any
reporter_civicpointsNumber of civic points the issue reporter has, if
any
reporter_avatar_fullChosen avatar of the issue reporter
reporter_avatar_squareSquare version of the avatar